Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(221)

Unified Diff: tools/testing/dart/test_suite.dart

Issue 23368003: Cleanup of isolate.status (first step) (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« tests/isolate/isolate.status ('K') | « tools/testing/dart/test_runner.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/testing/dart/test_suite.dart
diff --git a/tools/testing/dart/test_suite.dart b/tools/testing/dart/test_suite.dart
index 4f62e29916823b1eb57dac680cdcc58a31bbb52b..5f5e4efcaa360373ec23960e9c920440d88bcd38 100644
--- a/tools/testing/dart/test_suite.dart
+++ b/tools/testing/dart/test_suite.dart
@@ -355,7 +355,10 @@ class CCTestSuite extends TestSuite {
SummaryReport.add(expectations);
}
- if (expectations.contains(SKIP)) return;
+ if (expectations.contains(SKIP) ||
+ expectations.contains(SKIP_BY_DESIGN)) {
+ return;
+ }
var args = TestUtils.standardOptions(configuration);
args.add(testName);
@@ -683,7 +686,10 @@ class StandardTestSuite extends TestSuite {
SummaryReport.add(expectations);
}
}
- if (expectations.contains(SKIP)) return;
+ if (expectations.contains(SKIP) ||
+ expectations.contains(SKIP_BY_DESIGN)) {
+ return;
+ }
if (configuration['compiler'] != 'none' && info.hasCompileError) {
// If a compile-time error is expected, and we're testing a
@@ -1907,6 +1913,7 @@ class TestUtils {
class SummaryReport {
static int total = 0;
static int skipped = 0;
+ static int skippedByDesign = 0;
static int noCrash = 0;
static int pass = 0;
static int failOk = 0;
@@ -1919,6 +1926,9 @@ class SummaryReport {
++total;
if (expectations.contains(SKIP)) {
++skipped;
+ } else if (expectations.contains(SKIP_BY_DESIGN)) {
+ ++skipped;
+ ++skippedByDesign;
} else {
if (expectations.contains(PASS) && expectations.contains(FAIL) &&
!expectations.contains(CRASH) && !expectations.contains(OK)) {
@@ -1950,7 +1960,7 @@ class SummaryReport {
static void printReport() {
if (total == 0) return;
String report = """Total: $total tests
* $skipped tests will be skipped
* $noCrash tests are expected to be flaky but not crash
* $pass tests are expected to pass
* $failOk tests are expected to fail that we won't fix
@@ -1950,7 +1960,7 @@ class SummaryReport {
if (total == 0) return;
String report = """Total: $total tests
- * $skipped tests will be skipped
+ * $skipped tests will be skipped ($skippedByDesign skipped by design)
* $noCrash tests are expected to be flaky but not crash
* $pass tests are expected to pass
« tests/isolate/isolate.status ('K') | « tools/testing/dart/test_runner.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698